==> keras_cv_attention_models-1.2.13-py3-none-any.whl: keras_cv_attention_models/cmt/__init__.py <==
from keras_cv_attention_models.cmt.cmt import CMT, CMTTiny, CMTXS, CMTSmall, CMTBig

__head_doc__ = """
Keras implementation of [Github FlyEgle/CMT-pytorch](https://github.com/FlyEgle/CMT-pytorch).
Paper [PDF 2107.06263 CoAtNet: CMT: Convolutional Neural Networks Meet Vision Transformers](https://arxiv.org/pdf/2107.06263.pdf).
"""

__tail_doc__ = """  input_shape: it should have exactly 3 inputs channels, like `(224, 224, 3)`.
  num_classes: number of classes to classify images into. Set `0` to exclude top layers.
  activation: activation used in whole model, default `relu`.
  drop_connect_rate: is used for [Deep Networks with Stochastic Depth](https://arxiv.org/abs/1603.09382).
      Can be value like `0.2`, indicates the drop probability linearly changes from `0 --> 0.2` for `top --> bottom` layers.
      A higher value means a higher probability will drop the deep branch.
      or `0` to disable (default).
  classifier_activation: A `str` or callable. The activation function to use on the "top" layer if `num_classes > 0`.
      Set `classifier_activation=None` to return the logits of the "top" layer.
  dropout: dropout rate if top layers is included.
  pretrained: None or "imagenet". Only CMTTiny pretrained available.
  **kwargs: other parameters if available.

Returns:
    A `keras.Model` instance.
"""

CMT.__doc__ = __head_doc__ + """
Args:
  num_blocks: number of blocks in each stack.
  out_channels: output channels for each stack.
  stem_width: output dimension for stem block.
  num_heads: heads number for transformer block.
  sr_ratios:
  ffn_expansion:
  model_name: string, model name.
""" + __tail_doc__ + """
Model architectures:
  | Model    | Params | Image resolution | Top1 Acc |
  | -------- | ------ | ---------------- | -------- |
  | CMTTiny  | 9.5M   | 160              | 79.2     |
  | CMTXS    | 15.2M  | 192              | 81.8     |
  | CMTSmall | 25.1M  | 224              | 83.5     |
  | CMTBig   | 45.7M  | 256              | 84.5     |
"""

CMTTiny.__doc__ = __head_doc__ + """
Args:
""" + __tail_doc__

CMTXS.__doc__ = CMTTiny.__doc__
CMTSmall.__doc__ = CMTTiny.__doc__
CMTBig.__doc__ = CMTTiny.__doc__

==> keras_cv_attention_models-1.2.25-py3-none-any.whl: keras_cv_attention_models/cmt/__init__.py <==
from keras_cv_attention_models.cmt.cmt import CMT, CMTTiny, CMTXS, CMTSmall, CMTBig

__head_doc__ = """
Keras implementation of CMT.
Paper [PDF 2107.06263 CMT: Convolutional Neural Networks Meet Vision Transformers](https://arxiv.org/pdf/2107.06263.pdf).
"""

__tail_doc__ = """  input_shape: it should have exactly 3 inputs channels, like `(224, 224, 3)`.
  num_classes: number of classes to classify images into. Set `0` to exclude top layers.
  activation: activation used in whole model, default `relu`.
  drop_connect_rate: is used for [Deep Networks with Stochastic Depth](https://arxiv.org/abs/1603.09382).
      Can be value like `0.2`, indicates the drop probability linearly changes from `0 --> 0.2` for `top --> bottom` layers.
      A higher value means a higher probability will drop the deep branch.
      or `0` to disable (default).
  classifier_activation: A `str` or callable. The activation function to use on the "top" layer if `num_classes > 0`.
      Set `classifier_activation=None` to return the logits of the "top" layer.
  dropout: dropout rate if top layers is included.
  pretrained: None or "imagenet". Only CMTTiny pretrained available.
  **kwargs: other parameters if available.

Returns:
    A `keras.Model` instance.
"""

CMT.__doc__ = __head_doc__ + """
Args:
  num_blocks: number of blocks in each stack.
  out_channels: output channels for each stack.
  stem_width: output dimension for stem block.
  num_heads: heads number for transformer block.
  sr_ratios: attenstion blocks key_value downsample rate.
  ffn_expansion: IRFFN blocks hidden expansion rate.
  model_name: string, model name.
""" + __tail_doc__ + """
Model architectures:
  | Model                              | Params | FLOPs | Input | Top1 Acc |
  | ---------------------------------- | ------ | ----- | ----- | -------- |
  | CMTTiny, (Self trained 105 epochs) | 9.5M   | 0.65G | 160   | 77.4     |
  | - 305 epochs                       | 9.5M   | 0.65G | 160   | 78.94    |
  | - fine-tuned 224 (69 epochs)       | 9.5M   | 1.32G | 224   | 80.73    |
  | CMTTiny, 1000 epochs               | 9.5M   | 0.65G | 160   | 79.2     |
  | CMTXS                              | 15.2M  | 1.58G | 192   | 81.8     |
  | CMTSmall                           | 25.1M  | 4.09G | 224   | 83.5     |
  | CMTBig                             | 45.7M  | 9.42G | 256   | 84.5     |
"""

CMTTiny.__doc__ = __head_doc__ + """
Args:
""" + __tail_doc__

CMTXS.__doc__ = CMTTiny.__doc__
CMTSmall.__doc__ = CMTTiny.__doc__
CMTBig.__doc__ = CMTTiny.__doc__
